@@ -1,6 +1,7 @@
 """Global explanations explain the whole dataset or model behavior on that dataset.
 
 Todo:
+
     * More support for sampling methods
     * add support for other tasks than classification (e.g. regression, multi-label classification)
     * partial dependence plots? https://scikit-learn.org/stable/modules/classes.html#module-sklearn.inspection
@@ -71,15 +72,17 @@ class GlobalExplanation(Readable):
             explain_model (bool, optional): Whether to explain using the `model` 
                 labels (True) or `labelprovider` labels (False). Defaults to True.
 
+        Raises:
+            ValueError: if explain_model = True provide a model, and if False provide a labelprovider.
+
         Returns:
             Tuple[InstanceProvider, np.ndarray]: Instances and corresponding labels
         """
-        if explain_model:
-            assert model is not None, \
-                'Provide a model to explain its predictions, or set `explain_predictions` to False'
-        else:
-            assert labelprovider is not None, \
-                'Provide a labelprovider to explain ground-truth labels, or set `explain_predictions` to True'
+        if explain_model and model is None:
+            raise ValueError('Provide a model to explain its predictions, or set `explain_predictions` to False')
+        elif not explain_model and labelprovider is None:
+            raise ValueError('Provide a labelprovider to explain ground-truth labels, ',
+                             'or set `explain_predictions` to True')
 
         instances = self.get_data()
         labels = model.predict(instances) if explain_model \
@@ -88,6 +91,9 @@ class GlobalExplanation(Readable):
             labels = ['-'.join(list(x)) for id, x in labels]
         return instances, np.array(labels)
 
+    def explain(self, *args, **kwargs):
+        return self(*args, **kwargs)
+
 
 class TokenFrequency(GlobalExplanation):
     def __call__(self,
